@@ -40,9 +40,8 @@ void DUChainBench::initShell()
     AutoTestShell::init();
     TestCore* core = new TestCore();
     core->initialize(KDevelop::Core::NoUi);
-
     auto doc_url = QDir::cleanPath(QStandardPaths::locate(QStandardPaths::GenericDataLocation,
-                                                          "kdevpythonsupport/documentation_files/builtindocumentation.py"));
+                                                          QStringLiteral("kdevpythonsupport/documentation_files/builtindocumentation.py")));
 
     DUChain::self()->updateContextForUrl(IndexedString(doc_url), KDevelop::TopDUContext::AllDeclarationsContextsAndUses);
     ICore::self()->languageController()->backgroundParser()->parseDocuments();
@@ -54,7 +53,7 @@ void DUChainBench::initShell()
 
 ReferencedTopDUContext DUChainBench::parse(const QString& code)
 {
-    TestFile* testfile = new TestFile(code + "\n", "py", nullptr, testDir.absolutePath().append("/"));
+    TestFile* testfile = new TestFile(code + QLatin1Char('\n'), QStringLiteral("py"), nullptr, testDir.absolutePath().append(QLatin1Char('/')));
     createdFiles << testfile;
     testfile->parse(TopDUContext::ForceUpdate | TopDUContext::AST);
     testfile->waitForParsed(2000);
@@ -69,7 +68,7 @@ ReferencedTopDUContext DUChainBench::parse(const QString& code)
 
 DUChainBench::~DUChainBench()
 {
-    foreach ( TestFile* f, createdFiles ) {
+    for ( TestFile* f : createdFiles ) {
         delete f;
     }
     testDir.rmdir(testDir.absolutePath());
@@ -80,7 +79,7 @@ QString repeat_distinct(const QString& code, int count) {
     QString line;
     for ( int i = 0; i < count; i++ ) {
         line = code;
-        result.append(line.replace(QString("%X"), QString::number(i)));
+        result.append(line.replace(QStringLiteral("%X"), QString::number(i)));
     }
     return result;
 }
@@ -90,22 +89,22 @@ void DUChainBench::benchSimpleStatements_data()
     QTest::addColumn<QString>("code");
 
     // test assignment
-    QTest::newRow("test_nondistinct_assignment_repeated") << QString("a=3\n").repeated(200);
-    QTest::newRow("test_nondistinct_assignment_looped") << repeat_distinct(QString("a=%X\n"), 200);
-    QTest::newRow("test_distinct_assignment_repeated") << repeat_distinct(QString("a%X=3\n"), 200);
-    QTest::newRow("test_distinct_assignment_looped") << repeat_distinct(QString("a%X=%X\n"), 200);
+    QTest::newRow("test_nondistinct_assignment_repeated") << QStringLiteral("a=3\n").repeated(200);
+    QTest::newRow("test_nondistinct_assignment_looped") << repeat_distinct(QStringLiteral("a=%X\n"), 200);
+    QTest::newRow("test_distinct_assignment_repeated") << repeat_distinct(QStringLiteral("a%X=3\n"), 200);
+    QTest::newRow("test_distinct_assignment_looped") << repeat_distinct(QStringLiteral("a%X=%X\n"), 200);
     // test function
-    QTest::newRow("test_bare_function") << repeat_distinct(QString("def main%X():\n    pass\n"), 100);
-    QTest::newRow("test_return_function") << repeat_distinct(QString("def main%X():\n    return %X\n"), 100);
-    QTest::newRow("test_arg_function_return_var") << repeat_distinct(QString("def func%X(arg):\n    return arg\na%X = func%X(3)\n"), 200);
-    QTest::newRow("test_arg_function_return_fixed") << repeat_distinct(QString("def func%X(arg):\n    return 3\na%X = func%X()\n"), 200);
+    QTest::newRow("test_bare_function") << repeat_distinct(QStringLiteral("def main%X():\n    pass\n"), 100);
+    QTest::newRow("test_return_function") << repeat_distinct(QStringLiteral("def main%X():\n    return %X\n"), 100);
+    QTest::newRow("test_arg_function_return_var") << repeat_distinct(QStringLiteral("def func%X(arg):\n    return arg\na%X = func%X(3)\n"), 200);
+    QTest::newRow("test_arg_function_return_fixed") << repeat_distinct(QStringLiteral("def func%X(arg):\n    return 3\na%X = func%X()\n"), 200);
     // test if statements
-    QTest::newRow("test_if_statement") << repeat_distinct(QString("if(True):\n    pass\n"), 200);
-    QTest::newRow("test_if_else_statement") << repeat_distinct(QString("if(True):\n    pass\nelse:\n    pass\n"), 200);
+    QTest::newRow("test_if_statement") << repeat_distinct(QStringLiteral("if(True):\n    pass\n"), 200);
+    QTest::newRow("test_if_else_statement") << repeat_distinct(QStringLiteral("if(True):\n    pass\nelse:\n    pass\n"), 200);
     // test for loops
-    QTest::newRow("test_for_loop") << repeat_distinct(QString("for i in range(20):\n    pass\n"), 100);
-    QTest::newRow("test_for_loop_enum") << repeat_distinct(QString("for key, value in enumerate({1:2, 7:3}):\n    pass\n"), 200);
-    QTest::newRow("test_for_loop_list") << repeat_distinct(QString("for key, value in [(3, 5), (7, 9)]:\n    pass\n"), 200);
+    QTest::newRow("test_for_loop") << repeat_distinct(QStringLiteral("for i in range(20):\n    pass\n"), 100);
+    QTest::newRow("test_for_loop_enum") << repeat_distinct(QStringLiteral("for key, value in enumerate({1:2, 7:3}):\n    pass\n"), 200);
+    QTest::newRow("test_for_loop_list") << repeat_distinct(QStringLiteral("for key, value in [(3, 5), (7, 9)]:\n    pass\n"), 200);
 }
 
 void DUChainBench::benchSimpleStatements()
