@@ -13,7 +13,7 @@ QString AstTransformer::getattr(PyObject *obj, const char *attr) const
     if (PyUnicode_Check(v))
         return PyUnicodeObjectToQString(v);
     Py_XDECREF(v);
-    return "";
+    return QString();
 }
 
 template <>
@@ -1246,6 +1246,12 @@ Ast* AstTransformer::visitStmtNode(PyObject* node, Ast* parent)
         }
         result = v;
     }
+#endif
+#if PYTHON_VERSION >= QT_VERSION_CHECK(3, 12, 0)
+    else if (PyObject_IsInstance(node, grammar.ast_TypeAlias)) {
+        TypeAliasAst* v = new TypeAliasAst(parent);
+        result = v;
+    }
 #endif
     else {
         qWarning() << "Unsupported _stmt AST type: " << PyUnicodeObjectToQString(PyObject_Str(node));
@@ -1402,6 +1408,13 @@ Ast* AstTransformer::visitPatternNode(PyObject* node, Ast* parent)
         {
             QString name = getattr<QString>(node, "name");
             v->name = name.size() ? new Python::Identifier(name) : nullptr;
+            if (v->name) {
+                v->name->startLine = tline(getattr<int>(node, "end_lineno"));
+                v->name->endCol = getattr<int>(node, "end_col_offset") - 1;
+                v->name->endLine = v->name->startLine;
+                v->name->startCol = v->name->endCol - name.size() + 1;
+                v->copyRange(v->name);
+            }
         }
         result = v;
     }
